==============
Salt tutorials
==============

Introduction
============
.. toctree::
    :maxdepth: 2

    quickstart

Basics
======
.. toctree::
    :maxdepth: 2

    salt_bootstrap
    standalone_minion
    firewall
    cron
    modules
    pillar

States
======
.. toctree::
    :maxdepth: 2

    starting_states
    states_pt1
    states_pt2
    states_pt3
    states_pt4
    states_pt5
    states_ordering

Advanced Topics
================
.. toctree::
    :maxdepth: 2

    walkthrough
    minionfs
    esky
    multimaster
    preseed_key
    bootstrap_ec2
    salt_bootstrap
    gitfs
    walkthrough_macosx
    writing_tests

Salt Cloud
==========
.. toctree::
    :maxdepth: 2

    cloud_controller

Halite
======
.. toctree::
    :maxdepth: 2

    halite
